@@ -1,15 +1,21 @@
 # -*- coding: utf-8 -*-
 #CPE 1704 TKS
 """
-Module implementing MainWindow.
+Module implementing MainWindow GUI, anselA
 """
-import math
+
+import os
 import sys
 import EXIF
+import math
 import operator
-import os
-from PIL import Image, ImageEnhance, ImageDraw
-
+import webbrowser
+import AnselA_Filters as Filters
+import AnselA_Core as Core
+import AnselA_Graphics as Graphics
+from PIL import Image
+from PIL import ImageDraw
+from PIL import ImageEnhance
 from PyQt4 import QtGui
 from PyQt4 import QtCore 
 from PyQt4.QtGui import QMainWindow
@@ -17,71 +23,11 @@ from PyQt4.QtCore import pyqtSignature
 from Ui_mainWindow import Ui_MainWindow
 
 
-def Enhance(self, im, name, lo, hi):
-# set up the image
-    im=curIm
-    self.enhancer = enhancer(im)
-    self.update("1.0") # normalize
-
-    self.value = eval(value)
-    
-def MinMax():
-    if (self.isFullScreen):
-        self.showFullScreen()
-    else:
-        self.showNormal()
-
-def pil2qpixmap(pil_image):
-    w, h = pil_image.size
-    data = pil_image.tostring("raw", "BGRX")
-    qimage = QtGui.QImage(data, w, h, QtGui.QImage.Format_RGB32)
-    qpixmap = QtGui.QPixmap(w,h)
-    pix = QtGui.QPixmap.fromImage(qimage)
-    return pix
-
-def valToScalar(value): #, soft):
-    """
-    Calculates an appropiate value to scale from / to
-    """
-#    if (soft == True):
-#        if (value >0):
-#            return 1+(math.exp(2-((99-value)*6/100)))
-#        if (value <0):
-#            return 1-((math.exp(2-((99+value)*6/100)))/8)
-#        if (value ==0):
-#            return 1
-#    else:
-    if (value >0):
-        return 1+value/20.0
-    if (value <0):
-        return 1+(value*0.01)
-    if (value ==0):
-        return 1
-
-class MainWindow(QMainWindow, Ui_MainWindow):
+class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     """
     Main Window Class for AnselA
     """
-    valR = 0
-    valB = 0
-    valG = 0
-    valSa = 0
-    valBr = 0
-    valCo = 0
-    valHi =0
-    valMi =0
-    valSh =0
-    valSa =0
-    valRot = 0
-    valOrient = 0
-    valBW = "L"
-    wMaximized = True
-    lockUpdating = False
-    curImageLoc ="/opt/anselA/ui/resources/landscapeRepo.jpg"
-    plotIm = Image.open("/opt/anselA/ui/resources/graph.png") 
-    curIm =""
-    curThumb = ""
-    valCurTab=0
+    val=Core.ParamValues()
         
     def __init__(self, parent = None):
         """
@@ -89,14 +35,28 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         QMainWindow.__init__(self, parent)
         self.setupUi(self)
-        self.ImageOpen(self.curImageLoc)
+        self.ImageOpen(self.val.curImageLoc)
         self.postSetup()
-        self.ImageDisplayRefresh()
+        self.ImageDisplayRefresh(True)
+        self.ShowApply(False)
     
     def postSetup(self):
         self.tabStrip.setCurrentIndex(0)
+
+    @pyqtSignature("Bool")
+    def ShowApply(self, Show):
+        if self.val.ApplyVisible <> Show:
+            self.val.ApplyVisible = Show
+            if Show:
+                self.btnLevelApply.setVisible(True)
+                self.btnLevelReset.setVisible(True)
+            else:
+                self.btnLevelApply.setVisible(False)
+                self.btnLevelReset.setVisible(False)
         
+    @pyqtSignature("Bool, Image")
     def showUpdateLabel(self, show,  thumb):
+        self.ShowApply(True)
         self.lockUpdating = show
         if (thumb == True):
             if (show == True):
@@ -105,10 +65,10 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                 self.labWaitThumb.setGeometry(QtCore.QRect(30, 120, 0, 161))
         else:
             if (show == True):
-                self.tabPhoto.setCurrentIndex(1)
+                self.FullScreenToggle(True)
                 self.labWait.setGeometry(QtCore.QRect(0, 0, 800, 441))
             else:
-                self.tabPhoto.setCurrentIndex(0)
+                self.FullScreenToggle(False)
                 self.labWait.setGeometry(QtCore.QRect(0, 0, 0, 441))
         self.labWait.repaint()
         self.repaint()
@@ -119,56 +79,56 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        self.valBW = "L"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "L"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_Red_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "R"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "R"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_Green_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "G"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "G"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_Blue_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "B"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "B"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
  
     @pyqtSignature("")
     def on_btn_Yellow_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "Y"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "Y"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_Cyan_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "C"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "C"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_Magenta_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "M"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "M"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
 
 
     @pyqtSignature("")
@@ -176,20 +136,21 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        if (self.valCurTab == 5):
-            self.RotateApply(self.valRot)
-        elif (self.valCurTab == 1):
-            self.BWApply(self.curIm, self.valBW,  True)
+        if (self.val.valCurTab == 5):
+            self.RotateApply(self.val.valRot)
+        elif (self.val.valCurTab == 1):
+            self.BWApply(self.val.curIm, self.val.valBW,  True)
         else:
-            self.LevelApply(self.curIm,  True)           
+            self.LevelApply(self.val.curIm,  True)           
+        
+        self.ShowApply(False)
     
-    
-    @pyqtSignature("")
+    @pyqtSignature("Image,String,Bool")
     def BWApply(self, imageToEdit,  cSource,  UpdateRealImage):
         """
         Slot documentation goes here.
         """
-        if  (self.lockUpdating == False):
+        if  (self.val.lockUpdating == False):
             if (UpdateRealImage == True):
                 self.showUpdateLabel(True,  False)
             else:
@@ -266,10 +227,10 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 
             
             if (UpdateRealImage == True):
-                self.photo.setPixmap(pil2qpixmap(im))
+                self.photo.setPixmap(Core.pil2qpixmap(im))
                 self.showUpdateLabel(False,  False)
             else:
-                self.photo_Thumb.setPixmap(pil2qpixmap(im))
+                self.photo_Thumb.setPixmap(Core.pil2qpixmap(im))
                 self.showUpdateLabel(False,  True)
     
     @pyqtSignature("")
@@ -277,7 +238,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        if  (self.lockUpdating == False):
+        if  (self.val.lockUpdating == False):
             if (UpdateRealImage == True):
                 self.showUpdateLabel(True,  False)
             else:
@@ -287,22 +248,22 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             source = im.split()
             R, G, B = 0, 1, 2
 
-            out = source[R].point(lambda i: i *valToScalar(self.valR))
+            out = source[R].point(lambda i: i *Core.valToScalar(self.val.valR))
             source[R].paste(out, None, None)
 
-            out = source[G].point(lambda i: i *valToScalar(self.valG))
+            out = source[G].point(lambda i: i *Core.valToScalar(self.val.valG))
             source[G].paste(out, None, None)
 
-            out = source[B].point(lambda i: i *valToScalar(self.valB))
+            out = source[B].point(lambda i: i *Core.valToScalar(self.val.valB))
             source[B].paste(out, None, None)
             
             im = Image.merge(im.mode, source)
             
             if (UpdateRealImage == True):
-                self.photo.setPixmap(pil2qpixmap(im))
+                self.photo.setPixmap(Core.pil2qpixmap(im))
                 self.showUpdateLabel(False,  False)
             else:
-                self.photo_Thumb.setPixmap(pil2qpixmap(im))
+                self.photo_Thumb.setPixmap(Core.pil2qpixmap(im))
                 self.showUpdateLabel(False,  True)
     
     @pyqtSignature("int")
@@ -310,27 +271,27 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """ 
         Slot documentation goes here.
         """
-        self.valB = value
-        self.lcdB.setText(str(self.valB))
-        self.LevelApply(self.curThumb,  False)
+        self.val.valB = value
+        self.lcdB.setText(str(self.val.valB))
+        self.LevelApply(self.val.curThumb,  False)
     
     @pyqtSignature("int")
     def on_cSlide_R_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        self.valR = value
-        self.lcdR.setText(str(self.valR))
-        self.LevelApply(self.curThumb,  False)
+        self.val.valR = value
+        self.lcdR.setText(str(self.val.valR))
+        self.LevelApply(self.val.curThumb,  False)
     
     @pyqtSignature("int")
     def on_cSlide_G_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        self.valG = value
-        self.lcdG.setText(str(self.valG))
-        self.LevelApply(self.curThumb,  False)
+        self.val.valG = value
+        self.lcdG.setText(str(self.val.valG))
+        self.LevelApply(self.val.curThumb,  False)
     
     @pyqtSignature("")
     def on_btnLevelReset_released(self):
@@ -340,8 +301,8 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         self.cSlide_R.setValue(0)
         self.cSlide_G.setValue(0)
         self.cSlide_B.setValue(0)
-        self.LevelApply(self.curThumb,  False)
-        self.LevelApply(self.curIm,  True)
+        self.LevelApply(self.val.curThumb,  False)
+        self.LevelApply(self.val.curIm,  True)
     
     @pyqtSignature("")
     def on_minMax_released(self):
@@ -368,7 +329,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         elif (index==8):
             self.AnimateTab()
         else:
-            self.valCurTab = index
+            self.val.valCurTab = index
         
 
     @pyqtSignature("")
@@ -385,12 +346,12 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        if  (self.lockUpdating == False):
+        if  (self.val.lockUpdating == False):
             self.showUpdateLabel(True)
-            im = self.curIm
+            im = self.val.curIm
             enhancer = ImageEnhance.Brightness(im)
-            bright_im = enhancer.enhance(self.valL*-1*0.01) #any value you want
-            self.photo.setPixmap(pil2qpixmap(bright_im))
+            bright_im = enhancer.enhance(self.val.valL*-1*0.01) #any value you want
+            self.photo.setPixmap(Core.pil2qpixmap(bright_im))
             self.showUpdateLabel(False)
     
     @pyqtSignature("")
@@ -400,24 +361,27 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         ImgTemp= str(QtGui.QFileDialog.getOpenFileName(self, 'Open File', '/home/user/MyDocs/DCIM/', ("Images (*.png *.jpg)")))
         if ImgTemp != "":
-            self.curImageLoc = ImgTemp
-        self.ImageOpen(self.curImageLoc)
-        self.ImageDisplayRefresh()
+            self.val.curImageLoc = ImgTemp
+        self.ImageOpen(self.val.curImageLoc)
+        self.ImageDisplayRefresh(True)
         
-    def ImageDisplayRefresh(self):
+    @pyqtSignature("Bool")
+    def ImageDisplayRefresh(self,  LoadOriginal) :
         """
         Display image on GUI
         """
-        self.ImageLoad(self.curIm)
-        self.photo.setPixmap(pil2qpixmap(self.curIm))
-        self.photo_Orig.setPixmap(pil2qpixmap(self.curIm))
-        self.photo_Thumb.setPixmap(pil2qpixmap(self.curThumb))
+        self.ImageLoad(self.val.curIm,  False)
+        self.photo.setPixmap(Core.pil2qpixmap(self.val.curIm))
+        if LoadOriginal:
+            self.photo_Orig.setPixmap(Core.pil2qpixmap(self.val.curIm))
+        self.photo_Thumb.setPixmap(Core.pil2qpixmap(self.val.curThumb))
+        self.btnFullScreen.setGeometry(self.photo_Thumb.geometry())
     
     def ImageOpen(self, filename):
         """
         Open File and poulate class parameters of Image.
         """
-        self.curIm = Image.open(filename)
+        self.val.curIm = Image.open(filename)
         
         p = open(filename, "rb")
         tags = EXIF.process_file(p)
@@ -427,9 +391,9 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                 
                 if key == "Image Orientation":
                     if newItem == "Image Orientation: Horizontal (normal)":
-                        self.valOrient = 0
+                        self.val.valOrient = 0
                     else:
-                        self.valOrient = 1
+                        self.val.valOrient = 1
                     
                 if (newItem !="" and  newItem.startswith("Maker Note") == False  and  newItem.startswith("MakerNote") == False  and  newItem.startswith("EXIF") == False):
                     self.listEXIFData.addItem(newItem)
@@ -438,10 +402,11 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                 continue
                 #print "EXIF Error"
       
-        self.ImageLoad(self.curIm)
+        self.val.origIm = self.val.curIm.copy()
+        self.ImageLoad(self.val.curIm, True)
       
     def convertImSize(self, origW,  origH,  dConstraint):
-        if (self.valOrient == 0): #landscape
+        if (self.val.valOrient == 0): #landscape
             scale=origW/dConstraint
             newW=dConstraint
             newH=int(math.ceil(origH/scale))
@@ -451,18 +416,29 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             newW=int(math.ceil(origW/scale))
             
         return newW,  newH
+    
+    @pyqtSignature("Image, Bool")
+    def ImageLoad(self, im,  LoadOriginal):
         
-    def ImageLoad(self, im):
-        
-        self.curIm = im
-        w, h = self.curIm.size
-        #155, 195 is thumb center
+        self.val.curIm = im
+        w, h = self.val.curIm.size
         wTh,  hTh = self.convertImSize(w, h,  250)
-        
         self.photo_Thumb.setGeometry(QtCore.QRect(155-int(wTh/2), 195-int(hTh/2), wTh, hTh))
-        
+
         size = (wTh,  hTh )
-        self.curThumb = im.resize(size, Image.ANTIALIAS)
+        self.val.curThumb = im.resize(size, Image.ANTIALIAS)
+        self.photo_Thumb.repaint()
+        
+        if LoadOriginal:
+            wTh,  hTh = self.convertImSize(w, h,  800)
+            self.photo_Orig.setGeometry(QtCore.QRect(400-int(wTh/2), 220-int(hTh/2), wTh, hTh))
+            self.photo_Orig.repaint()
+            
+        wTh,  hTh = self.convertImSize(w, h,  800)
+        self.photo.setGeometry(QtCore.QRect(400-int(wTh/2), 220-int(hTh/2), wTh, hTh))
+        self.photo.repaint()
+
+        #800, 440
         #self.curThumb.thumbnail(size, Image.ANTIALIAS)
         # resize makes a copy thumbnail modifies
         #self.ImageDisplayOrig()
@@ -473,10 +449,10 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        if (index == 0):
-            self.FullScreenToggle(False)
-        else:
-            self.FullScreenToggle(True)
+#        if (index == 0):
+#            self.FullScreenToggle(False)
+#        else:
+#            self.FullScreenToggle(True)
 
 #+++++++++++++++++++++++ END of Class    
     
@@ -486,89 +462,91 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        self.valHi = value
-        self.lcdHi.setText(str(self.valHi))
+        self.val.valHi = value
+        self.lcdHi.setText(str(self.val.valHi))
     
     @pyqtSignature("int")
     def on_cSlide_Mi_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        self.valMi = value
-        self.lcdMi.setText(str(self.valMi))
+        self.val.valMi = value
+        self.lcdMi.setText(str(self.val.valMi))
     
     @pyqtSignature("int")
     def on_cSlide_Sh_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        self.valSh = value
-        self.lcdSh.setText(str(self.valSh))
+        self.val.valSh = value
+        self.lcdSh.setText(str(self.val.valSh))
     
     @pyqtSignature("int")
     def on_cSlide_Sa_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        self.valSa = value
-        self.lcdSa.setText(str(self.valSa))
+        self.val.valSa = value
+        self.lcdSa.setText(str(self.val.valSa))
         
     @pyqtSignature("int")
     def on_cSlide_Sw_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        self.valSw = value
-        self.lcdSw.setText(str(self.valSw))
+        self.val.valSw = value
+        self.lcdSw.setText(str(self.val.valSw))
     
     @pyqtSignature("int")
     def on_cSlide_Co_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        self.valCo = value
-        self.lcdCo.setText(str(self.valCo))
+        self.val.valCo = value
+        self.lcdCo.setText(str(self.val.valCo))
     
     @pyqtSignature("int")
     def on_cSlide_Br_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        self.valBr = value
-        self.lcdBr.setText(str(self.valBr))
+        self.val.valBr = value
+        self.lcdBr.setText(str(self.val.valBr))
     
     @pyqtSignature("int")
     def on_dial_valueChanged(self, value):
         """
         Slot documentation goes here.
         """
-        if  (self.lockUpdating == False):
-            self.valRot = value
-            self.lcdRot_1.setText(str(self.valRot))
+        if  (self.val.lockUpdating == False):
+            self.val.valRot = value
+            self.lcdRot_1.setText(str(self.val.valRot))
             self.RotateThumb(value)
            
 
     def RotateThumb(self, rotation):
         self.showUpdateLabel(True,  True)
-        im=self.curThumb
+        im=self.val.curThumb
         
         im = im.rotate(rotation,  resample=Image.BICUBIC,  expand=0)
         draw = ImageDraw.Draw(im)
         draw.rectangle(self.RotateCalc(rotation, im))
         
         del draw
-        self.photo_Thumb.setPixmap(pil2qpixmap(im))
+        self.photo_Thumb.setPixmap(Core.pil2qpixmap(im))
         self.showUpdateLabel(False,  True)
         
     def RotateApply(self, rotation):
-        self.showUpdateLabel(True,  False)
-        im=self.curIm
-        im = im.rotate(rotation,  resample=Image.BICUBIC,  expand=0)
-        w1, h1, w2, h2 = self.RotateCalc(rotation, im)
-        
-        self.curIm = im.crop((w1, h1, w2, h2))
-        self.ImageDisplayRefresh()
-        self.showUpdateLabel(False,  False)
+        if  (self.val.lockUpdating == False):
+            self.showUpdateLabel(True,  False)
+            im=self.val.curIm
+            im = im.rotate(rotation,  resample=Image.BICUBIC,  expand=0)
+            w1, h1, w2, h2 = self.RotateCalc(rotation, im)
+            
+            self.val.curIm = im.crop((w1, h1, w2, h2))
+            self.ImageDisplayRefresh(False)
+            self.showUpdateLabel(False,  False)
+            self.val.lockUpdating = False
         
     def RotateCalc(self, rotation,  im):
 
@@ -598,7 +576,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 
     @pyqtSignature("")
     def on_btnExitCancel_released(self):
-        self.tabStrip.setCurrentIndex(self.valCurTab)
+        self.tabStrip.setCurrentIndex(self.val.valCurTab)
         self.frameExitRequest.setGeometry(QtCore.QRect(0, 0, 0, 0))
         
     @pyqtSignature("")
@@ -678,12 +656,12 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         Slot documentation goes here.
         """
         if (Show):
-            self.tabPhoto.setCurrentIndex(1)
-            self.tabPhoto.setGeometry(QtCore.QRect(0, 40, 800, 480))    
-            self.tabStrip.setGeometry(QtCore.QRect(190, 120, 691, 491))
+            self.tabPhoto.setCurrentIndex(0)
+            self.framePhoto.setGeometry(QtCore.QRect(0, 0, 800, 480))    
+            #self.tabStrip.setGeometry(QtCore.QRect(190, 120, 691, 491))
         else:
-            self.tabPhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
-            self.tabStrip.setGeometry(QtCore.QRect(190, 40, 691, 491))
+            self.framePhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
+            #self.tabStrip.setGeometry(QtCore.QRect(190, 40, 691, 491))
             self.photo.repaint()
             self.photo_Orig.repaint()
             
@@ -696,55 +674,55 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         Slot documentation goes here.
         """
-        self.valBW = "BC"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "BC"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_GC_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "GC"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "GC"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_GY_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "GY"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "GY"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_BM_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "BM"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "BM"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
         
     @pyqtSignature("")
     def on_btn_RM_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "RM"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "RM"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
     
     @pyqtSignature("")
     def on_btn_RY_released(self):
         """
         Slot documentation goes here.
         """
-        self.valBW = "RY"
-        self.BWApply(self.curThumb,  self.valBW,  False)
+        self.val.valBW = "RY"
+        self.BWApply(self.val.curThumb,  self.val.valBW,  False)
 
     @pyqtSignature("")
     def ReturnHistPlots(self):
         """
         Slot documentation goes here.
         """
-        histo=self.curIm.histogram()
+        histo=self.val.curIm.histogram()
         OrignX=37
         OrignY=108
 
@@ -758,13 +736,13 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             ProcVal =int(valY/ScaleMax)
             plotList.append(ProcVal)
     
-        plotR = Image.new("RGB", self.plotIm.size)
-        plotG = Image.new("RGB", self.plotIm.size)
-        plotB = Image.new("RGB", self.plotIm.size)
+        plotR = Image.new("RGB", self.val.plotIm.size)
+        plotG = Image.new("RGB", self.val.plotIm.size)
+        plotB = Image.new("RGB", self.val.plotIm.size)
         
-        plotR.paste(self.plotIm)# = self.poltIm.copy()
-        plotG.paste(self.plotIm)
-        plotB.paste(self.plotIm)
+        plotR.paste(self.val.plotIm)# = self.val.poltIm.copy()
+        plotG.paste(self.val.plotIm)
+        plotB.paste(self.val.plotIm)
         
         drawR = ImageDraw.Draw(plotR)
         drawG = ImageDraw.Draw(plotG)
@@ -783,15 +761,20 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 
         #return plotIm
         
-        self.graphRed.setPixmap(pil2qpixmap(plotR.convert("RGB")))
-        self.graphGreen.setPixmap(pil2qpixmap(plotG.convert("RGB")))
-        self.graphBlue.setPixmap(pil2qpixmap(plotB.convert("RGB")))
+        self.graphRed.setPixmap(Core.pil2qpixmap(plotR.convert("RGB")))
+        self.graphGreen.setPixmap(Core.pil2qpixmap(plotG.convert("RGB")))
+        self.graphBlue.setPixmap(Core.pil2qpixmap(plotB.convert("RGB")))
     
+    
+    @pyqtSignature("")
+    def on_btnBug_released(self):
+        """
+        Slot documentation goes here.
+        """
+ 
+        webbrowser.open("https://bugs.maemo.org/enter_bug.cgi?product=AnselA")
+        
+        
+    
+
         
-#        for x in range(255):
-#            plotX =OrignX + x
-#            sortCol=sorted(((x,plotList[x],"red"),(x+256,plotList[x+256],"green"),(x+512,plotList[x+512],"blue")), key=operator.itemgetter(1))
-#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[2][1]], fill=sortCol[2][2])
-#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[1][1]], fill=sortCol[1][2])
-#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[0][1]], fill=sortCol[0][2])
-#        del draw 
